document.addEventListener('DOMContentLoaded', () => {
  // Theme toggler
  const themeToggle = document.querySelector('.theme-toggle');
  const prefersDark = window.matchMedia('(prefers-color-scheme: dark)');
  
  function setTheme(isDark) {
    document.documentElement.setAttribute('data-theme', isDark ? 'dark' : 'light');
    themeToggle.textContent = isDark ? '🌞' : '🌓';
  }
  
  setTheme(prefersDark.matches);
  
  themeToggle.addEventListener('click', () => {
    const isDark = document.documentElement.getAttribute('data-theme') === 'dark';
    setTheme(!isDark);
  });

  // Animate bars
  const bars = document.querySelectorAll('.bar');
  
  function setBarWidths() {
    bars.forEach(bar => {
      const value = parseFloat(bar.dataset.value);
      const parent = bar.parentElement;
      const maxValue = Array.from(parent.children)
        .map(child => parseFloat(child.dataset.value))
        .reduce((a, b) => Math.max(a, b));
      
      const width = (value / maxValue * 100);
      bar.style.setProperty('width', width + '%');
      bar.querySelector('::before').style.setProperty('width', '100%');
    });
  }

  // Intersection Observer for animation
  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        setBarWidths();
        observer.unobserve(entry.target);
      }
    });
  }, { threshold: 0.1 });

  document.querySelectorAll('.metric-card').forEach(card => {
    observer.observe(card);
  });
});
